# slow5lib Documentation

Welcome to the slow5lib documentation.

[Getting started](getting_started.md)

[slow5 API for C](slow5_api/slow5.md)

[pyslow5 API for Python](pyslow5_api/pyslow5.md)

[SLOW5 specification](https://hasindu2008.github.io/slow5specs)

[slow5tools](https://github.com/hasindu2008/slow5tools)

Please cite the following in your publications when using *slow5lib/pyslow5*:

> Gamaarachchi, H., Samarakoon, H., Jenner, S.P. et al. Fast nanopore sequencing data analysis with SLOW5. Nat Biotechnol 40, 1026-1029 (2022). https://doi.org/10.1038/s41587-021-01147-4

```
@article{gamaarachchi2022fast,
  title={Fast nanopore sequencing data analysis with SLOW5},
  author={Gamaarachchi, Hasindu and Samarakoon, Hiruna and Jenner, Sasha P and Ferguson, James M and Amos, Timothy G and Hammond, Jillian M and Saadat, Hassaan and Smith, Martin A and Parameswaran, Sri and Deveson, Ira W},
  journal={Nature biotechnology},
  pages={1--4},
  year={2022},
  publisher={Nature Publishing Group}
}
```
